# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_recoveryservices_siterecovery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9azure/azure_microsoft_recoveryservices_siterecovery.proto\x12\x39oak9.tython.azure.microsoft_recoveryservices_siterecovery\x1a\x13shared/shared.proto\"\xaf\n\n\'Microsoft_RecoveryServices_SiteRecovery\x12\x84\x01\n!vaults_replication_alert_settings\x18\x01 \x03(\x0b\x32Y.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationAlertSettings\x12w\n\x1avaults_replication_fabrics\x18\x02 \x03(\x0b\x32S.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabrics\x12\xd7\x01\nLvaults_replication_fabrics_replication_networks_replication_network_mappings\x18\x03 \x03(\x0b\x32\x80\x01.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings\x12\x91\x02\njvaults_replication_fabrics_replication_storage_classifications_replication_storage_classification_mappings\x18\x04 \x03(\x0b\x32\x9c\x01.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings\x12y\n\x1bvaults_replication_policies\x18\x05 \x03(\x0b\x32T.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationPolicies\x12\x8c\x01\n%vaults_replication_protection_intents\x18\x06 \x03(\x0b\x32].oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationProtectionIntents\x12\x84\x01\n!vaults_replication_recovery_plans\x18\x07 \x03(\x0b\x32Y.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationRecoveryPlans\x12\x84\x01\n!vaults_replication_vault_settings\x18\x08 \x03(\x0b\x32Y.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationVaultSettings\"\xad\x01\n\x1eVaultsReplicationVaultSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1d\n\x15migration_solution_id\x18\x03 \x01(\t\x12%\n\x1dvmware_to_azure_provider_type\x18\x04 \x01(\t\"\x9e\x03\n\x1eVaultsReplicationRecoveryPlans\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12!\n\x19\x66\x61ilover_deployment_model\x18\x03 \x01(\t\x12\\\n\x06groups\x18\x04 \x03(\x0b\x32L.oak9.tython.azure.microsoft_recoveryservices_siterecovery.RecoveryPlanGroup\x12\x19\n\x11primary_fabric_id\x18\x05 \x01(\t\x12}\n\x17provider_specific_input\x18\x06 \x03(\x0b\x32\\.oak9.tython.azure.microsoft_recoveryservices_siterecovery.RecoveryPlanProviderSpecificInput\x12\x1a\n\x12recovery_fabric_id\x18\x07 \x01(\t\"1\n!RecoveryPlanProviderSpecificInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf8\x02\n\x11RecoveryPlanGroup\x12h\n\x11\x65nd_group_actions\x18\x01 \x03(\x0b\x32M.oak9.tython.azure.microsoft_recoveryservices_siterecovery.RecoveryPlanAction\x12\x12\n\ngroup_type\x18\x02 \x01(\t\x12y\n\x1breplication_protected_items\x18\x03 \x03(\x0b\x32T.oak9.tython.azure.microsoft_recoveryservices_siterecovery.RecoveryPlanProtectedItem\x12j\n\x13start_group_actions\x18\x04 \x03(\x0b\x32M.oak9.tython.azure.microsoft_recoveryservices_siterecovery.RecoveryPlanAction\"C\n\x19RecoveryPlanProtectedItem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1a\n\x12virtual_machine_id\x18\x02 \x01(\t\"\xcc\x01\n\x12RecoveryPlanAction\x12\x13\n\x0b\x61\x63tion_name\x18\x01 \x01(\t\x12l\n\x0e\x63ustom_details\x18\x02 \x01(\x0b\x32T.oak9.tython.azure.microsoft_recoveryservices_siterecovery.RecoveryPlanActionDetails\x12\x1b\n\x13\x66\x61ilover_directions\x18\x03 \x03(\t\x12\x16\n\x0e\x66\x61ilover_types\x18\x04 \x03(\t\")\n\x19RecoveryPlanActionDetails\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf9\x01\n\"VaultsReplicationProtectionIntents\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x8b\x01\n\x19provider_specific_details\x18\x03 \x01(\x0b\x32h.oak9.tython.azure.microsoft_recoveryservices_siterecovery.CreateProtectionIntentProviderSpecificDetails\"=\n-CreateProtectionIntentProviderSpecificDetails\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xdb\x01\n\x19VaultsReplicationPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12w\n\x17provider_specific_input\x18\x03 \x01(\x0b\x32V.oak9.tython.azure.microsoft_recoveryservices_siterecovery.PolicyProviderSpecificInput\"+\n\x1bPolicyProviderSpecificInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xe3\x01\n+VaultsReplicationFabricsReplicationvCenters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rfriendly_name\x18\x03 \x01(\t\x12\x12\n\nip_address\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\t\x12\x19\n\x11process_server_id\x18\x06 \x01(\t\x12\x19\n\x11run_as_account_id\x18\x07 \x01(\t\"\xd4\x01\naVaultsReplicationFabricsReplicationStorageClassificationsReplicationStorageClassificationMappings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12(\n target_storage_classification_id\x18\x03 \x01(\t\"\xb8\x04\n<VaultsReplicationFabricsReplicationRecoveryServicesProviders\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12w\n\x1d\x61uthentication_identity_input\x18\x03 \x01(\x0b\x32P.oak9.tython.azure.microsoft_recoveryservices_siterecovery.IdentityProviderInput\x12\x0f\n\x07\x62ios_id\x18\x04 \x01(\t\x12\x82\x01\n(data_plane_authentication_identity_input\x18\x05 \x01(\x0b\x32P.oak9.tython.azure.microsoft_recoveryservices_siterecovery.IdentityProviderInput\x12\x12\n\nmachine_id\x18\x06 \x01(\t\x12\x14\n\x0cmachine_name\x18\x07 \x01(\t\x12x\n\x1eresource_access_identity_input\x18\x08 \x01(\x0b\x32P.oak9.tython.azure.microsoft_recoveryservices_siterecovery.IdentityProviderInput\"~\n\x15IdentityProviderInput\x12\x15\n\raad_authority\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\t\x12\x10\n\x08\x61udience\x18\x03 \x01(\t\x12\x11\n\tobject_id\x18\x04 \x01(\t\x12\x11\n\ttenant_id\x18\x05 \x01(\t\"\xf0\x02\n]VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tpolicy_id\x18\x03 \x01(\t\x12\x8c\x01\n\x17provider_specific_input\x18\x04 \x01(\x0b\x32k.oak9.tython.azure.microsoft_recoveryservices_siterecovery.ReplicationProviderSpecificContainerMappingInput\x12&\n\x1etarget_protection_container_id\x18\x05 \x01(\t\"@\n0ReplicationProviderSpecificContainerMappingInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xcf\x02\nPVaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tpolicy_id\x18\x03 \x01(\t\x12\x1b\n\x13protectable_item_id\x18\x04 \x01(\t\x12\x83\x01\n\x19provider_specific_details\x18\x05 \x01(\x0b\x32`.oak9.tython.azure.microsoft_recoveryservices_siterecovery.EnableProtectionProviderSpecificInput\"5\n%EnableProtectionProviderSpecificInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xb1\x02\nPVaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tpolicy_id\x18\x03 \x01(\t\x12\x82\x01\n\x19provider_specific_details\x18\x04 \x01(\x0b\x32_.oak9.tython.azure.microsoft_recoveryservices_siterecovery.EnableMigrationProviderSpecificInput\"4\n$EnableMigrationProviderSpecificInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xfe\x07\n7VaultsReplicationFabricsReplicationProtectionContainers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x8d\x01\n\x17provider_specific_input\x18\x03 \x03(\x0b\x32l.oak9.tython.azure.microsoft_recoveryservices_siterecovery.ReplicationProviderSpecificContainerCreationInput\x12\xee\x01\nXvaults_replication_fabrics_replication_protection_containers_replication_migration_items\x18\x04 \x03(\x0b\x32\x8b\x01.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationProtectionContainersReplicationMigrationItems\x12\xee\x01\nXvaults_replication_fabrics_replication_protection_containers_replication_protected_items\x18\x05 \x03(\x0b\x32\x8b\x01.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectedItems\x12\x89\x02\nfvaults_replication_fabrics_replication_protection_containers_replication_protection_container_mappings\x18\x06 \x03(\x0b\x32\x98\x01.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationProtectionContainersReplicationProtectionContainerMappings\"A\n1ReplicationProviderSpecificContainerCreationInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xcf\x02\nEVaultsReplicationFabricsReplicationNetworksReplicationNetworkMappings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x83\x01\n\x17\x66\x61\x62ric_specific_details\x18\x03 \x01(\x0b\x32\x62.oak9.tython.azure.microsoft_recoveryservices_siterecovery.FabricSpecificCreateNetworkMappingInput\x12\x1c\n\x14recovery_fabric_name\x18\x04 \x01(\t\x12\x1b\n\x13recovery_network_id\x18\x05 \x01(\t\"7\n\'FabricSpecificCreateNetworkMappingInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf4\x05\n\x18VaultsReplicationFabrics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12n\n\x0e\x63ustom_details\x18\x03 \x01(\x0b\x32V.oak9.tython.azure.microsoft_recoveryservices_siterecovery.FabricSpecificCreationInput\x12\xb8\x01\n<vaults_replication_fabrics_replication_protection_containers\x18\x04 \x03(\x0b\x32r.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationProtectionContainers\x12\xc3\x01\nBvaults_replication_fabrics_replication_recovery_services_providers\x18\x05 \x03(\x0b\x32w.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationRecoveryServicesProviders\x12\x9f\x01\n/vaults_replication_fabrics_replicationv_centers\x18\x06 \x03(\x0b\x32\x66.oak9.tython.azure.microsoft_recoveryservices_siterecovery.VaultsReplicationFabricsReplicationvCenters\"+\n\x1b\x46\x61\x62ricSpecificCreationInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xaf\x01\n\x1eVaultsReplicationAlertSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1e\n\x16\x63ustom_email_addresses\x18\x03 \x03(\t\x12\x0e\n\x06locale\x18\x04 \x01(\t\x12\x16\n\x0esend_to_owners\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_recoveryservices_siterecovery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MICROSOFT_RECOVERYSERVICES_SITERECOVERY._serialized_start=142
  _MICROSOFT_RECOVERYSERVICES_SITERECOVERY._serialized_end=1469
  _VAULTSREPLICATIONVAULTSETTINGS._serialized_start=1472
  _VAULTSREPLICATIONVAULTSETTINGS._serialized_end=1645
  _VAULTSREPLICATIONRECOVERYPLANS._serialized_start=1648
  _VAULTSREPLICATIONRECOVERYPLANS._serialized_end=2062
  _RECOVERYPLANPROVIDERSPECIFICINPUT._serialized_start=2064
  _RECOVERYPLANPROVIDERSPECIFICINPUT._serialized_end=2113
  _RECOVERYPLANGROUP._serialized_start=2116
  _RECOVERYPLANGROUP._serialized_end=2492
  _RECOVERYPLANPROTECTEDITEM._serialized_start=2494
  _RECOVERYPLANPROTECTEDITEM._serialized_end=2561
  _RECOVERYPLANACTION._serialized_start=2564
  _RECOVERYPLANACTION._serialized_end=2768
  _RECOVERYPLANACTIONDETAILS._serialized_start=2770
  _RECOVERYPLANACTIONDETAILS._serialized_end=2811
  _VAULTSREPLICATIONPROTECTIONINTENTS._serialized_start=2814
  _VAULTSREPLICATIONPROTECTIONINTENTS._serialized_end=3063
  _CREATEPROTECTIONINTENTPROVIDERSPECIFICDETAILS._serialized_start=3065
  _CREATEPROTECTIONINTENTPROVIDERSPECIFICDETAILS._serialized_end=3126
  _VAULTSREPLICATIONPOLICIES._serialized_start=3129
  _VAULTSREPLICATIONPOLICIES._serialized_end=3348
  _POLICYPROVIDERSPECIFICINPUT._serialized_start=3350
  _POLICYPROVIDERSPECIFICINPUT._serialized_end=3393
  _VAULTSREPLICATIONFABRICSREPLICATIONVCENTERS._serialized_start=3396
  _VAULTSREPLICATIONFABRICSREPLICATIONVCENTERS._serialized_end=3623
  _VAULTSREPLICATIONFABRICSREPLICATIONSTORAGECLASSIFICATIONSREPLICATIONSTORAGECLASSIFICATIONMAPPINGS._serialized_start=3626
  _VAULTSREPLICATIONFABRICSREPLICATIONSTORAGECLASSIFICATIONSREPLICATIONSTORAGECLASSIFICATIONMAPPINGS._serialized_end=3838
  _VAULTSREPLICATIONFABRICSREPLICATIONRECOVERYSERVICESPROVIDERS._serialized_start=3841
  _VAULTSREPLICATIONFABRICSREPLICATIONRECOVERYSERVICESPROVIDERS._serialized_end=4409
  _IDENTITYPROVIDERINPUT._serialized_start=4411
  _IDENTITYPROVIDERINPUT._serialized_end=4537
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERSREPLICATIONPROTECTIONCONTAINERMAPPINGS._serialized_start=4540
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERSREPLICATIONPROTECTIONCONTAINERMAPPINGS._serialized_end=4908
  _REPLICATIONPROVIDERSPECIFICCONTAINERMAPPINGINPUT._serialized_start=4910
  _REPLICATIONPROVIDERSPECIFICCONTAINERMAPPINGINPUT._serialized_end=4974
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERSREPLICATIONPROTECTEDITEMS._serialized_start=4977
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERSREPLICATIONPROTECTEDITEMS._serialized_end=5312
  _ENABLEPROTECTIONPROVIDERSPECIFICINPUT._serialized_start=5314
  _ENABLEPROTECTIONPROVIDERSPECIFICINPUT._serialized_end=5367
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERSREPLICATIONMIGRATIONITEMS._serialized_start=5370
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERSREPLICATIONMIGRATIONITEMS._serialized_end=5675
  _ENABLEMIGRATIONPROVIDERSPECIFICINPUT._serialized_start=5677
  _ENABLEMIGRATIONPROVIDERSPECIFICINPUT._serialized_end=5729
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERS._serialized_start=5732
  _VAULTSREPLICATIONFABRICSREPLICATIONPROTECTIONCONTAINERS._serialized_end=6754
  _REPLICATIONPROVIDERSPECIFICCONTAINERCREATIONINPUT._serialized_start=6756
  _REPLICATIONPROVIDERSPECIFICCONTAINERCREATIONINPUT._serialized_end=6821
  _VAULTSREPLICATIONFABRICSREPLICATIONNETWORKSREPLICATIONNETWORKMAPPINGS._serialized_start=6824
  _VAULTSREPLICATIONFABRICSREPLICATIONNETWORKSREPLICATIONNETWORKMAPPINGS._serialized_end=7159
  _FABRICSPECIFICCREATENETWORKMAPPINGINPUT._serialized_start=7161
  _FABRICSPECIFICCREATENETWORKMAPPINGINPUT._serialized_end=7216
  _VAULTSREPLICATIONFABRICS._serialized_start=7219
  _VAULTSREPLICATIONFABRICS._serialized_end=7975
  _FABRICSPECIFICCREATIONINPUT._serialized_start=7977
  _FABRICSPECIFICCREATIONINPUT._serialized_end=8020
  _VAULTSREPLICATIONALERTSETTINGS._serialized_start=8023
  _VAULTSREPLICATIONALERTSETTINGS._serialized_end=8198
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.certificates.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6kubernetes/kubernetes_io.k8s.api.certificates.v1.proto\x12#oak9.tython.k8s.api.certificates.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xec\x02\n\x19\x43\x65rtificateSigningRequest\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12P\n\x04spec\x18\x04 \x01(\x0b\x32\x42.oak9.tython.k8s.api.certificates.v1.CertificateSigningRequestSpec\x12T\n\x06status\x18\x05 \x01(\x0b\x32\x44.oak9.tython.k8s.api.certificates.v1.CertificateSigningRequestStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbe\x02\n\"CertificateSigningRequestCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12M\n\x10last_update_time\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x95\x02\n\x1d\x43\x65rtificateSigningRequestList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12M\n\x05items\x18\x02 \x03(\x0b\x32>.oak9.tython.k8s.api.certificates.v1.CertificateSigningRequest\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe5\x02\n\x1d\x43\x65rtificateSigningRequestSpec\x12\x1a\n\x12\x65xpiration_seconds\x18\x01 \x01(\x05\x12\\\n\x05\x65xtra\x18\x02 \x03(\x0b\x32M.oak9.tython.k8s.api.certificates.v1.CertificateSigningRequestSpec.ExtraEntry\x12\x0e\n\x06groups\x18\x03 \x03(\t\x12\x0f\n\x07request\x18\x04 \x01(\t\x12\x13\n\x0bsigner_name\x18\x05 \x01(\t\x12\x0b\n\x03uid\x18\x06 \x01(\t\x12\x0e\n\x06usages\x18\x07 \x03(\t\x12\x10\n\x08username\x18\x08 \x01(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcc\x01\n\x1f\x43\x65rtificateSigningRequestStatus\x12\x13\n\x0b\x63\x65rtificate\x18\x01 \x01(\t\x12[\n\nconditions\x18\x02 \x03(\x0b\x32G.oak9.tython.k8s.api.certificates.v1.CertificateSigningRequestCondition\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.certificates.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CERTIFICATESIGNINGREQUESTSPEC_EXTRAENTRY._options = None
  _CERTIFICATESIGNINGREQUESTSPEC_EXTRAENTRY._serialized_options = b'8\001'
  _CERTIFICATESIGNINGREQUEST._serialized_start=183
  _CERTIFICATESIGNINGREQUEST._serialized_end=547
  _CERTIFICATESIGNINGREQUESTCONDITION._serialized_start=550
  _CERTIFICATESIGNINGREQUESTCONDITION._serialized_end=868
  _CERTIFICATESIGNINGREQUESTLIST._serialized_start=871
  _CERTIFICATESIGNINGREQUESTLIST._serialized_end=1148
  _CERTIFICATESIGNINGREQUESTSPEC._serialized_start=1151
  _CERTIFICATESIGNINGREQUESTSPEC._serialized_end=1508
  _CERTIFICATESIGNINGREQUESTSPEC_EXTRAENTRY._serialized_start=1464
  _CERTIFICATESIGNINGREQUESTSPEC_EXTRAENTRY._serialized_end=1508
  _CERTIFICATESIGNINGREQUESTSTATUS._serialized_start=1511
  _CERTIFICATESIGNINGREQUESTSTATUS._serialized_end=1715
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_applicationGateways(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_GATEWAYS_FIELD_NUMBER: builtins.int
    APPLICATION_GATEWAY_WEB_APPLICATION_FIREWALL_POLICIES_FIELD_NUMBER: builtins.int
    @property
    def application_gateways(self) -> global___ApplicationGateways: ...
    @property
    def application_gateway_web_application_firewall_policies(self) -> global___ApplicationGatewayWebApplicationFirewallPolicies: ...
    def __init__(
        self,
        *,
        application_gateways: global___ApplicationGateways | None = ...,
        application_gateway_web_application_firewall_policies: global___ApplicationGatewayWebApplicationFirewallPolicies | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application_gateway_web_application_firewall_policies", b"application_gateway_web_application_firewall_policies", "application_gateways", b"application_gateways"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_gateway_web_application_firewall_policies", b"application_gateway_web_application_firewall_policies", "application_gateways", b"application_gateways"]) -> None: ...

global___Microsoft_Network_applicationGateways = Microsoft_Network_applicationGateways

@typing_extensions.final
class HttpListener(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___HttpListener = HttpListener

@typing_extensions.final
class BackendHttpSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___BackendHttpSettings = BackendHttpSettings

@typing_extensions.final
class BackendAddressPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___BackendAddressPool = BackendAddressPool

@typing_extensions.final
class FrontendPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___FrontendPort = FrontendPort

@typing_extensions.final
class FrontendIPConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___FrontendIPConfiguration = FrontendIPConfiguration

@typing_extensions.final
class Subnet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___Subnet = Subnet

@typing_extensions.final
class PublicIpAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PublicIpAddress = PublicIpAddress

@typing_extensions.final
class ApplicationGatewaysPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationGatewaysPrivateEndpointConnections = ApplicationGatewaysPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    status: builtins.str
    description: builtins.str
    actions_required: builtins.str
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        description: builtins.str = ...,
        actions_required: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class ApplicationGateways(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    SSL_POLICY_FIELD_NUMBER: builtins.int
    GATEWAY_IP_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    AUTHENTICATION_CERTIFICATES_FIELD_NUMBER: builtins.int
    TRUSTED_ROOT_CERTIFICATES_FIELD_NUMBER: builtins.int
    TRUSTED_CLIENT_CERTIFICATES_FIELD_NUMBER: builtins.int
    SSL_CERTIFICATES_FIELD_NUMBER: builtins.int
    FRONTEND_IP_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    FRONTEND_PORTS_FIELD_NUMBER: builtins.int
    PROBES_FIELD_NUMBER: builtins.int
    BACKEND_ADDRESS_POOLS_FIELD_NUMBER: builtins.int
    BACKEND_HTTP_SETTINGS_COLLECTION_FIELD_NUMBER: builtins.int
    HTTP_LISTENERS_FIELD_NUMBER: builtins.int
    SSL_PROFILES_FIELD_NUMBER: builtins.int
    URL_PATH_MAPS_FIELD_NUMBER: builtins.int
    REQUEST_ROUTING_RULES_FIELD_NUMBER: builtins.int
    REWRITE_RULE_SETS_FIELD_NUMBER: builtins.int
    REDIRECT_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    WEB_APPLICATION_FIREWALL_CONFIGURATION_FIELD_NUMBER: builtins.int
    FIREWALL_POLICY_FIELD_NUMBER: builtins.int
    ENABLE_HTTP2_FIELD_NUMBER: builtins.int
    ENABLE_FIPS_FIELD_NUMBER: builtins.int
    AUTOSCALE_CONFIGURATION_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    CUSTOM_ERROR_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    FORCE_FIREWALL_POLICY_ASSOCIATION_FIELD_NUMBER: builtins.int
    ZONES_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    APPLICATION_GATEWAYS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def sku(self) -> global___ApplicationGatewaySku: ...
    @property
    def ssl_policy(self) -> global___ApplicationGatewaySslPolicy: ...
    @property
    def gateway_ip_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayIPConfiguration]: ...
    @property
    def authentication_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayAuthenticationCertificate]: ...
    @property
    def trusted_root_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayTrustedRootCertificate]: ...
    @property
    def trusted_client_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayTrustedClientCertificate]: ...
    @property
    def ssl_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewaySslCertificate]: ...
    @property
    def frontend_ip_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayFrontendIPConfiguration]: ...
    @property
    def frontend_ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayFrontendPort]: ...
    @property
    def probes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayProbe]: ...
    @property
    def backend_address_pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayBackendAddressPool]: ...
    @property
    def backend_http_settings_collection(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayBackendHttpSettings]: ...
    @property
    def http_listeners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayHttpListener]: ...
    @property
    def ssl_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewaySslProfile]: ...
    @property
    def url_path_maps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayUrlPathMap]: ...
    @property
    def request_routing_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayRequestRoutingRule]: ...
    @property
    def rewrite_rule_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayRewriteRuleSet]: ...
    @property
    def redirect_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayRedirectConfiguration]: ...
    @property
    def web_application_firewall_configuration(self) -> global___ApplicationGatewayWebApplicationFirewallConfiguration: ...
    firewall_policy: builtins.str
    enable_http2: builtins.bool
    enable_fips: builtins.bool
    @property
    def autoscale_configuration(self) -> global___ApplicationGatewayAutoscaleConfiguration: ...
    @property
    def private_link_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayPrivateLinkConfiguration]: ...
    @property
    def custom_error_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayCustomError]: ...
    force_firewall_policy_association: builtins.bool
    @property
    def zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    @property
    def application_gateways_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewaysPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        sku: global___ApplicationGatewaySku | None = ...,
        ssl_policy: global___ApplicationGatewaySslPolicy | None = ...,
        gateway_ip_configurations: collections.abc.Iterable[global___ApplicationGatewayIPConfiguration] | None = ...,
        authentication_certificates: collections.abc.Iterable[global___ApplicationGatewayAuthenticationCertificate] | None = ...,
        trusted_root_certificates: collections.abc.Iterable[global___ApplicationGatewayTrustedRootCertificate] | None = ...,
        trusted_client_certificates: collections.abc.Iterable[global___ApplicationGatewayTrustedClientCertificate] | None = ...,
        ssl_certificates: collections.abc.Iterable[global___ApplicationGatewaySslCertificate] | None = ...,
        frontend_ip_configurations: collections.abc.Iterable[global___ApplicationGatewayFrontendIPConfiguration] | None = ...,
        frontend_ports: collections.abc.Iterable[global___ApplicationGatewayFrontendPort] | None = ...,
        probes: collections.abc.Iterable[global___ApplicationGatewayProbe] | None = ...,
        backend_address_pools: collections.abc.Iterable[global___ApplicationGatewayBackendAddressPool] | None = ...,
        backend_http_settings_collection: collections.abc.Iterable[global___ApplicationGatewayBackendHttpSettings] | None = ...,
        http_listeners: collections.abc.Iterable[global___ApplicationGatewayHttpListener] | None = ...,
        ssl_profiles: collections.abc.Iterable[global___ApplicationGatewaySslProfile] | None = ...,
        url_path_maps: collections.abc.Iterable[global___ApplicationGatewayUrlPathMap] | None = ...,
        request_routing_rules: collections.abc.Iterable[global___ApplicationGatewayRequestRoutingRule] | None = ...,
        rewrite_rule_sets: collections.abc.Iterable[global___ApplicationGatewayRewriteRuleSet] | None = ...,
        redirect_configurations: collections.abc.Iterable[global___ApplicationGatewayRedirectConfiguration] | None = ...,
        web_application_firewall_configuration: global___ApplicationGatewayWebApplicationFirewallConfiguration | None = ...,
        firewall_policy: builtins.str = ...,
        enable_http2: builtins.bool = ...,
        enable_fips: builtins.bool = ...,
        autoscale_configuration: global___ApplicationGatewayAutoscaleConfiguration | None = ...,
        private_link_configurations: collections.abc.Iterable[global___ApplicationGatewayPrivateLinkConfiguration] | None = ...,
        custom_error_configurations: collections.abc.Iterable[global___ApplicationGatewayCustomError] | None = ...,
        force_firewall_policy_association: builtins.bool = ...,
        zones: collections.abc.Iterable[builtins.str] | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        application_gateways_private_endpoint_connections: collections.abc.Iterable[global___ApplicationGatewaysPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscale_configuration", b"autoscale_configuration", "identity", b"identity", "resource_info", b"resource_info", "sku", b"sku", "ssl_policy", b"ssl_policy", "web_application_firewall_configuration", b"web_application_firewall_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_gateways_private_endpoint_connections", b"application_gateways_private_endpoint_connections", "authentication_certificates", b"authentication_certificates", "autoscale_configuration", b"autoscale_configuration", "backend_address_pools", b"backend_address_pools", "backend_http_settings_collection", b"backend_http_settings_collection", "custom_error_configurations", b"custom_error_configurations", "enable_fips", b"enable_fips", "enable_http2", b"enable_http2", "firewall_policy", b"firewall_policy", "force_firewall_policy_association", b"force_firewall_policy_association", "frontend_ip_configurations", b"frontend_ip_configurations", "frontend_ports", b"frontend_ports", "gateway_ip_configurations", b"gateway_ip_configurations", "http_listeners", b"http_listeners", "identity", b"identity", "location", b"location", "name", b"name", "private_link_configurations", b"private_link_configurations", "probes", b"probes", "redirect_configurations", b"redirect_configurations", "request_routing_rules", b"request_routing_rules", "resource_info", b"resource_info", "rewrite_rule_sets", b"rewrite_rule_sets", "sku", b"sku", "ssl_certificates", b"ssl_certificates", "ssl_policy", b"ssl_policy", "ssl_profiles", b"ssl_profiles", "tags", b"tags", "trusted_client_certificates", b"trusted_client_certificates", "trusted_root_certificates", b"trusted_root_certificates", "url_path_maps", b"url_path_maps", "web_application_firewall_configuration", b"web_application_firewall_configuration", "zones", b"zones"]) -> None: ...

global___ApplicationGateways = ApplicationGateways

@typing_extensions.final
class ManagedServiceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ManagedServiceIdentity = ManagedServiceIdentity

@typing_extensions.final
class ApplicationGatewayPrivateLinkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def ip_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayPrivateLinkIpConfiguration]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        ip_configurations: collections.abc.Iterable[global___ApplicationGatewayPrivateLinkIpConfiguration] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_configurations", b"ip_configurations", "name", b"name"]) -> None: ...

global___ApplicationGatewayPrivateLinkConfiguration = ApplicationGatewayPrivateLinkConfiguration

@typing_extensions.final
class ApplicationGatewayPrivateLinkIpConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_IP_ADDRESS_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ALLOCATION_METHOD_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    PRIMARY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    private_ip_address: builtins.str
    private_ip_allocation_method: builtins.str
    @property
    def subnet(self) -> global___Subnet: ...
    primary: builtins.bool
    name: builtins.str
    def __init__(
        self,
        *,
        private_ip_address: builtins.str = ...,
        private_ip_allocation_method: builtins.str = ...,
        subnet: global___Subnet | None = ...,
        primary: builtins.bool = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subnet", b"subnet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "primary", b"primary", "private_ip_address", b"private_ip_address", "private_ip_allocation_method", b"private_ip_allocation_method", "subnet", b"subnet"]) -> None: ...

global___ApplicationGatewayPrivateLinkIpConfiguration = ApplicationGatewayPrivateLinkIpConfiguration

@typing_extensions.final
class ApplicationGatewayAutoscaleConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_CAPACITY_FIELD_NUMBER: builtins.int
    MAX_CAPACITY_FIELD_NUMBER: builtins.int
    min_capacity: builtins.int
    max_capacity: builtins.int
    def __init__(
        self,
        *,
        min_capacity: builtins.int = ...,
        max_capacity: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_capacity", b"max_capacity", "min_capacity", b"min_capacity"]) -> None: ...

global___ApplicationGatewayAutoscaleConfiguration = ApplicationGatewayAutoscaleConfiguration

@typing_extensions.final
class ApplicationGatewayWebApplicationFirewallConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    FIREWALL_MODE_FIELD_NUMBER: builtins.int
    RULE_SET_TYPE_FIELD_NUMBER: builtins.int
    RULE_SET_VERSION_FIELD_NUMBER: builtins.int
    DISABLED_RULE_GROUPS_FIELD_NUMBER: builtins.int
    REQUEST_BODY_CHECK_FIELD_NUMBER: builtins.int
    MAX_REQUEST_BODY_SIZE_FIELD_NUMBER: builtins.int
    MAX_REQUEST_BODY_SIZE_IN_KB_FIELD_NUMBER: builtins.int
    FILE_UPLOAD_LIMIT_IN_MB_FIELD_NUMBER: builtins.int
    EXCLUSIONS_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    firewall_mode: builtins.str
    rule_set_type: builtins.str
    rule_set_version: builtins.str
    @property
    def disabled_rule_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayFirewallDisabledRuleGroup]: ...
    request_body_check: builtins.bool
    max_request_body_size: builtins.int
    max_request_body_size_in_kb: builtins.int
    file_upload_limit_in_mb: builtins.int
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayFirewallExclusion]: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        firewall_mode: builtins.str = ...,
        rule_set_type: builtins.str = ...,
        rule_set_version: builtins.str = ...,
        disabled_rule_groups: collections.abc.Iterable[global___ApplicationGatewayFirewallDisabledRuleGroup] | None = ...,
        request_body_check: builtins.bool = ...,
        max_request_body_size: builtins.int = ...,
        max_request_body_size_in_kb: builtins.int = ...,
        file_upload_limit_in_mb: builtins.int = ...,
        exclusions: collections.abc.Iterable[global___ApplicationGatewayFirewallExclusion] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled_rule_groups", b"disabled_rule_groups", "enabled", b"enabled", "exclusions", b"exclusions", "file_upload_limit_in_mb", b"file_upload_limit_in_mb", "firewall_mode", b"firewall_mode", "max_request_body_size", b"max_request_body_size", "max_request_body_size_in_kb", b"max_request_body_size_in_kb", "request_body_check", b"request_body_check", "rule_set_type", b"rule_set_type", "rule_set_version", b"rule_set_version"]) -> None: ...

global___ApplicationGatewayWebApplicationFirewallConfiguration = ApplicationGatewayWebApplicationFirewallConfiguration

@typing_extensions.final
class ApplicationGatewayFirewallExclusion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_VARIABLE_FIELD_NUMBER: builtins.int
    SELECTOR_MATCH_OPERATOR_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    match_variable: builtins.str
    selector_match_operator: builtins.str
    selector: builtins.str
    def __init__(
        self,
        *,
        match_variable: builtins.str = ...,
        selector_match_operator: builtins.str = ...,
        selector: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_variable", b"match_variable", "selector", b"selector", "selector_match_operator", b"selector_match_operator"]) -> None: ...

global___ApplicationGatewayFirewallExclusion = ApplicationGatewayFirewallExclusion

@typing_extensions.final
class ApplicationGatewayFirewallDisabledRuleGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_GROUP_NAME_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    rule_group_name: builtins.str
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        rule_group_name: builtins.str = ...,
        rules: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rule_group_name", b"rule_group_name", "rules", b"rules"]) -> None: ...

global___ApplicationGatewayFirewallDisabledRuleGroup = ApplicationGatewayFirewallDisabledRuleGroup

@typing_extensions.final
class ApplicationGatewayRedirectConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REDIRECT_TYPE_FIELD_NUMBER: builtins.int
    TARGET_LISTENER_FIELD_NUMBER: builtins.int
    TARGET_URL_FIELD_NUMBER: builtins.int
    INCLUDE_PATH_FIELD_NUMBER: builtins.int
    INCLUDE_QUERY_STRING_FIELD_NUMBER: builtins.int
    REQUEST_ROUTING_RULES_FIELD_NUMBER: builtins.int
    URL_PATH_MAPS_FIELD_NUMBER: builtins.int
    PATH_RULES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    redirect_type: builtins.str
    target_listener: builtins.str
    target_url: builtins.str
    include_path: builtins.bool
    include_query_string: builtins.bool
    @property
    def request_routing_rules(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def url_path_maps(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def path_rules(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        redirect_type: builtins.str = ...,
        target_listener: builtins.str = ...,
        target_url: builtins.str = ...,
        include_path: builtins.bool = ...,
        include_query_string: builtins.bool = ...,
        request_routing_rules: collections.abc.Iterable[builtins.str] | None = ...,
        url_path_maps: collections.abc.Iterable[builtins.str] | None = ...,
        path_rules: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["include_path", b"include_path", "include_query_string", b"include_query_string", "name", b"name", "path_rules", b"path_rules", "redirect_type", b"redirect_type", "request_routing_rules", b"request_routing_rules", "target_listener", b"target_listener", "target_url", b"target_url", "url_path_maps", b"url_path_maps"]) -> None: ...

global___ApplicationGatewayRedirectConfiguration = ApplicationGatewayRedirectConfiguration

@typing_extensions.final
class ApplicationGatewayRewriteRuleSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REWRITE_RULES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def rewrite_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayRewriteRule]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        rewrite_rules: collections.abc.Iterable[global___ApplicationGatewayRewriteRule] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "rewrite_rules", b"rewrite_rules"]) -> None: ...

global___ApplicationGatewayRewriteRuleSet = ApplicationGatewayRewriteRuleSet

@typing_extensions.final
class ApplicationGatewayRewriteRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RULE_SEQUENCE_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    ACTION_SET_FIELD_NUMBER: builtins.int
    name: builtins.str
    rule_sequence: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayRewriteRuleCondition]: ...
    @property
    def action_set(self) -> global___ApplicationGatewayRewriteRuleActionSet: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        rule_sequence: builtins.int = ...,
        conditions: collections.abc.Iterable[global___ApplicationGatewayRewriteRuleCondition] | None = ...,
        action_set: global___ApplicationGatewayRewriteRuleActionSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action_set", b"action_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_set", b"action_set", "conditions", b"conditions", "name", b"name", "rule_sequence", b"rule_sequence"]) -> None: ...

global___ApplicationGatewayRewriteRule = ApplicationGatewayRewriteRule

@typing_extensions.final
class ApplicationGatewayRewriteRuleActionSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADER_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    RESPONSE_HEADER_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    URL_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def request_header_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayHeaderConfiguration]: ...
    @property
    def response_header_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayHeaderConfiguration]: ...
    @property
    def url_configuration(self) -> global___ApplicationGatewayUrlConfiguration: ...
    def __init__(
        self,
        *,
        request_header_configurations: collections.abc.Iterable[global___ApplicationGatewayHeaderConfiguration] | None = ...,
        response_header_configurations: collections.abc.Iterable[global___ApplicationGatewayHeaderConfiguration] | None = ...,
        url_configuration: global___ApplicationGatewayUrlConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["url_configuration", b"url_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_header_configurations", b"request_header_configurations", "response_header_configurations", b"response_header_configurations", "url_configuration", b"url_configuration"]) -> None: ...

global___ApplicationGatewayRewriteRuleActionSet = ApplicationGatewayRewriteRuleActionSet

@typing_extensions.final
class ApplicationGatewayUrlConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODIFIED_PATH_FIELD_NUMBER: builtins.int
    MODIFIED_QUERY_STRING_FIELD_NUMBER: builtins.int
    REROUTE_FIELD_NUMBER: builtins.int
    modified_path: builtins.str
    modified_query_string: builtins.str
    reroute: builtins.bool
    def __init__(
        self,
        *,
        modified_path: builtins.str = ...,
        modified_query_string: builtins.str = ...,
        reroute: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["modified_path", b"modified_path", "modified_query_string", b"modified_query_string", "reroute", b"reroute"]) -> None: ...

global___ApplicationGatewayUrlConfiguration = ApplicationGatewayUrlConfiguration

@typing_extensions.final
class ApplicationGatewayHeaderConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value"]) -> None: ...

global___ApplicationGatewayHeaderConfiguration = ApplicationGatewayHeaderConfiguration

@typing_extensions.final
class ApplicationGatewayRewriteRuleCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VARIABLE_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    IGNORE_CASE_FIELD_NUMBER: builtins.int
    NEGATE_FIELD_NUMBER: builtins.int
    variable: builtins.str
    pattern: builtins.str
    ignore_case: builtins.bool
    negate: builtins.bool
    def __init__(
        self,
        *,
        variable: builtins.str = ...,
        pattern: builtins.str = ...,
        ignore_case: builtins.bool = ...,
        negate: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ignore_case", b"ignore_case", "negate", b"negate", "pattern", b"pattern", "variable", b"variable"]) -> None: ...

global___ApplicationGatewayRewriteRuleCondition = ApplicationGatewayRewriteRuleCondition

@typing_extensions.final
class ApplicationGatewayRequestRoutingRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_TYPE_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    BACKEND_ADDRESS_POOL_FIELD_NUMBER: builtins.int
    BACKEND_HTTP_SETTINGS_FIELD_NUMBER: builtins.int
    HTTP_LISTENER_FIELD_NUMBER: builtins.int
    URL_PATH_MAP_FIELD_NUMBER: builtins.int
    REWRITE_RULE_SET_FIELD_NUMBER: builtins.int
    REDIRECT_CONFIGURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    rule_type: builtins.str
    priority: builtins.int
    @property
    def backend_address_pool(self) -> global___BackendAddressPool: ...
    @property
    def backend_http_settings(self) -> global___BackendHttpSettings: ...
    @property
    def http_listener(self) -> global___HttpListener: ...
    url_path_map: builtins.str
    rewrite_rule_set: builtins.str
    redirect_configuration: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        rule_type: builtins.str = ...,
        priority: builtins.int = ...,
        backend_address_pool: global___BackendAddressPool | None = ...,
        backend_http_settings: global___BackendHttpSettings | None = ...,
        http_listener: global___HttpListener | None = ...,
        url_path_map: builtins.str = ...,
        rewrite_rule_set: builtins.str = ...,
        redirect_configuration: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backend_address_pool", b"backend_address_pool", "backend_http_settings", b"backend_http_settings", "http_listener", b"http_listener"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_address_pool", b"backend_address_pool", "backend_http_settings", b"backend_http_settings", "http_listener", b"http_listener", "name", b"name", "priority", b"priority", "redirect_configuration", b"redirect_configuration", "rewrite_rule_set", b"rewrite_rule_set", "rule_type", b"rule_type", "url_path_map", b"url_path_map"]) -> None: ...

global___ApplicationGatewayRequestRoutingRule = ApplicationGatewayRequestRoutingRule

@typing_extensions.final
class ApplicationGatewayUrlPathMap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_BACKEND_ADDRESS_POOL_FIELD_NUMBER: builtins.int
    DEFAULT_BACKEND_HTTP_SETTINGS_FIELD_NUMBER: builtins.int
    DEFAULT_REWRITE_RULE_SET_FIELD_NUMBER: builtins.int
    DEFAULT_REDIRECT_CONFIGURATION_FIELD_NUMBER: builtins.int
    PATH_RULES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    default_backend_address_pool: builtins.str
    default_backend_http_settings: builtins.str
    default_rewrite_rule_set: builtins.str
    default_redirect_configuration: builtins.str
    @property
    def path_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayPathRule]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        default_backend_address_pool: builtins.str = ...,
        default_backend_http_settings: builtins.str = ...,
        default_rewrite_rule_set: builtins.str = ...,
        default_redirect_configuration: builtins.str = ...,
        path_rules: collections.abc.Iterable[global___ApplicationGatewayPathRule] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_backend_address_pool", b"default_backend_address_pool", "default_backend_http_settings", b"default_backend_http_settings", "default_redirect_configuration", b"default_redirect_configuration", "default_rewrite_rule_set", b"default_rewrite_rule_set", "name", b"name", "path_rules", b"path_rules"]) -> None: ...

global___ApplicationGatewayUrlPathMap = ApplicationGatewayUrlPathMap

@typing_extensions.final
class ApplicationGatewayPathRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATHS_FIELD_NUMBER: builtins.int
    BACKEND_ADDRESS_POOL_FIELD_NUMBER: builtins.int
    BACKEND_HTTP_SETTINGS_FIELD_NUMBER: builtins.int
    REDIRECT_CONFIGURATION_FIELD_NUMBER: builtins.int
    REWRITE_RULE_SET_FIELD_NUMBER: builtins.int
    FIREWALL_POLICY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def backend_address_pool(self) -> global___BackendAddressPool: ...
    @property
    def backend_http_settings(self) -> global___BackendHttpSettings: ...
    redirect_configuration: builtins.str
    rewrite_rule_set: builtins.str
    firewall_policy: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
        backend_address_pool: global___BackendAddressPool | None = ...,
        backend_http_settings: global___BackendHttpSettings | None = ...,
        redirect_configuration: builtins.str = ...,
        rewrite_rule_set: builtins.str = ...,
        firewall_policy: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backend_address_pool", b"backend_address_pool", "backend_http_settings", b"backend_http_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_address_pool", b"backend_address_pool", "backend_http_settings", b"backend_http_settings", "firewall_policy", b"firewall_policy", "name", b"name", "paths", b"paths", "redirect_configuration", b"redirect_configuration", "rewrite_rule_set", b"rewrite_rule_set"]) -> None: ...

global___ApplicationGatewayPathRule = ApplicationGatewayPathRule

@typing_extensions.final
class ApplicationGatewaySslProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRUSTED_CLIENT_CERTIFICATES_FIELD_NUMBER: builtins.int
    SSL_POLICY_FIELD_NUMBER: builtins.int
    CLIENT_AUTH_CONFIGURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def trusted_client_certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ssl_policy(self) -> global___ApplicationGatewaySslPolicy: ...
    @property
    def client_auth_configuration(self) -> global___ApplicationGatewayClientAuthConfiguration: ...
    name: builtins.str
    def __init__(
        self,
        *,
        trusted_client_certificates: collections.abc.Iterable[builtins.str] | None = ...,
        ssl_policy: global___ApplicationGatewaySslPolicy | None = ...,
        client_auth_configuration: global___ApplicationGatewayClientAuthConfiguration | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_auth_configuration", b"client_auth_configuration", "ssl_policy", b"ssl_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_auth_configuration", b"client_auth_configuration", "name", b"name", "ssl_policy", b"ssl_policy", "trusted_client_certificates", b"trusted_client_certificates"]) -> None: ...

global___ApplicationGatewaySslProfile = ApplicationGatewaySslProfile

@typing_extensions.final
class ApplicationGatewayClientAuthConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERIFY_CLIENT_CERT_ISSUER_D_N_FIELD_NUMBER: builtins.int
    verify_client_cert_issuer_d_n: builtins.bool
    def __init__(
        self,
        *,
        verify_client_cert_issuer_d_n: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["verify_client_cert_issuer_d_n", b"verify_client_cert_issuer_d_n"]) -> None: ...

global___ApplicationGatewayClientAuthConfiguration = ApplicationGatewayClientAuthConfiguration

@typing_extensions.final
class ApplicationGatewayHttpListener(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FRONTEND_IP_CONFIGURATION_FIELD_NUMBER: builtins.int
    FRONTEND_PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    SSL_CERTIFICATE_FIELD_NUMBER: builtins.int
    SSL_PROFILE_FIELD_NUMBER: builtins.int
    REQUIRE_SERVER_NAME_INDICATION_FIELD_NUMBER: builtins.int
    CUSTOM_ERROR_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    FIREWALL_POLICY_FIELD_NUMBER: builtins.int
    HOST_NAMES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def frontend_ip_configuration(self) -> global___FrontendIPConfiguration: ...
    @property
    def frontend_port(self) -> global___FrontendPort: ...
    protocol: builtins.str
    host_name: builtins.str
    ssl_certificate: builtins.str
    ssl_profile: builtins.str
    require_server_name_indication: builtins.bool
    @property
    def custom_error_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayCustomError]: ...
    firewall_policy: builtins.str
    @property
    def host_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        frontend_ip_configuration: global___FrontendIPConfiguration | None = ...,
        frontend_port: global___FrontendPort | None = ...,
        protocol: builtins.str = ...,
        host_name: builtins.str = ...,
        ssl_certificate: builtins.str = ...,
        ssl_profile: builtins.str = ...,
        require_server_name_indication: builtins.bool = ...,
        custom_error_configurations: collections.abc.Iterable[global___ApplicationGatewayCustomError] | None = ...,
        firewall_policy: builtins.str = ...,
        host_names: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["frontend_ip_configuration", b"frontend_ip_configuration", "frontend_port", b"frontend_port"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_error_configurations", b"custom_error_configurations", "firewall_policy", b"firewall_policy", "frontend_ip_configuration", b"frontend_ip_configuration", "frontend_port", b"frontend_port", "host_name", b"host_name", "host_names", b"host_names", "name", b"name", "protocol", b"protocol", "require_server_name_indication", b"require_server_name_indication", "ssl_certificate", b"ssl_certificate", "ssl_profile", b"ssl_profile"]) -> None: ...

global___ApplicationGatewayHttpListener = ApplicationGatewayHttpListener

@typing_extensions.final
class ApplicationGatewayCustomError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_CODE_FIELD_NUMBER: builtins.int
    CUSTOM_ERROR_PAGE_URL_FIELD_NUMBER: builtins.int
    status_code: builtins.str
    custom_error_page_url: builtins.str
    def __init__(
        self,
        *,
        status_code: builtins.str = ...,
        custom_error_page_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_error_page_url", b"custom_error_page_url", "status_code", b"status_code"]) -> None: ...

global___ApplicationGatewayCustomError = ApplicationGatewayCustomError

@typing_extensions.final
class ApplicationGatewayBackendHttpSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    COOKIE_BASED_AFFINITY_FIELD_NUMBER: builtins.int
    REQUEST_TIMEOUT_FIELD_NUMBER: builtins.int
    PROBE_FIELD_NUMBER: builtins.int
    AUTHENTICATION_CERTIFICATES_FIELD_NUMBER: builtins.int
    TRUSTED_ROOT_CERTIFICATES_FIELD_NUMBER: builtins.int
    CONNECTION_DRAINING_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    PICK_HOST_NAME_FROM_BACKEND_ADDRESS_FIELD_NUMBER: builtins.int
    AFFINITY_COOKIE_NAME_FIELD_NUMBER: builtins.int
    PROBE_ENABLED_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    port: builtins.int
    protocol: builtins.str
    cookie_based_affinity: builtins.str
    request_timeout: builtins.int
    probe: builtins.str
    @property
    def authentication_certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def trusted_root_certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def connection_draining(self) -> global___ApplicationGatewayConnectionDraining: ...
    host_name: builtins.str
    pick_host_name_from_backend_address: builtins.bool
    affinity_cookie_name: builtins.str
    probe_enabled: builtins.bool
    path: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        port: builtins.int = ...,
        protocol: builtins.str = ...,
        cookie_based_affinity: builtins.str = ...,
        request_timeout: builtins.int = ...,
        probe: builtins.str = ...,
        authentication_certificates: collections.abc.Iterable[builtins.str] | None = ...,
        trusted_root_certificates: collections.abc.Iterable[builtins.str] | None = ...,
        connection_draining: global___ApplicationGatewayConnectionDraining | None = ...,
        host_name: builtins.str = ...,
        pick_host_name_from_backend_address: builtins.bool = ...,
        affinity_cookie_name: builtins.str = ...,
        probe_enabled: builtins.bool = ...,
        path: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connection_draining", b"connection_draining"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["affinity_cookie_name", b"affinity_cookie_name", "authentication_certificates", b"authentication_certificates", "connection_draining", b"connection_draining", "cookie_based_affinity", b"cookie_based_affinity", "host_name", b"host_name", "name", b"name", "path", b"path", "pick_host_name_from_backend_address", b"pick_host_name_from_backend_address", "port", b"port", "probe", b"probe", "probe_enabled", b"probe_enabled", "protocol", b"protocol", "request_timeout", b"request_timeout", "trusted_root_certificates", b"trusted_root_certificates"]) -> None: ...

global___ApplicationGatewayBackendHttpSettings = ApplicationGatewayBackendHttpSettings

@typing_extensions.final
class ApplicationGatewayConnectionDraining(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    DRAIN_TIMEOUT_IN_SEC_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    drain_timeout_in_sec: builtins.int
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        drain_timeout_in_sec: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["drain_timeout_in_sec", b"drain_timeout_in_sec", "enabled", b"enabled"]) -> None: ...

global___ApplicationGatewayConnectionDraining = ApplicationGatewayConnectionDraining

@typing_extensions.final
class ApplicationGatewayBackendAddressPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_ADDRESSES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def backend_addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationGatewayBackendAddress]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        backend_addresses: collections.abc.Iterable[global___ApplicationGatewayBackendAddress] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_addresses", b"backend_addresses", "name", b"name"]) -> None: ...

global___ApplicationGatewayBackendAddressPool = ApplicationGatewayBackendAddressPool

@typing_extensions.final
class ApplicationGatewayBackendAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FQDN_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    fqdn: builtins.str
    ip_address: builtins.str
    def __init__(
        self,
        *,
        fqdn: builtins.str = ...,
        ip_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fqdn", b"fqdn", "ip_address", b"ip_address"]) -> None: ...

global___ApplicationGatewayBackendAddress = ApplicationGatewayBackendAddress

@typing_extensions.final
class ApplicationGatewayProbe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTOCOL_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    UNHEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    PICK_HOST_NAME_FROM_BACKEND_HTTP_SETTINGS_FIELD_NUMBER: builtins.int
    MIN_SERVERS_FIELD_NUMBER: builtins.int
    MATCH_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    protocol: builtins.str
    host: builtins.str
    path: builtins.str
    interval: builtins.int
    timeout: builtins.int
    unhealthy_threshold: builtins.int
    pick_host_name_from_backend_http_settings: builtins.bool
    min_servers: builtins.int
    @property
    def match(self) -> global___ApplicationGatewayProbeHealthResponseMatch: ...
    port: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        protocol: builtins.str = ...,
        host: builtins.str = ...,
        path: builtins.str = ...,
        interval: builtins.int = ...,
        timeout: builtins.int = ...,
        unhealthy_threshold: builtins.int = ...,
        pick_host_name_from_backend_http_settings: builtins.bool = ...,
        min_servers: builtins.int = ...,
        match: global___ApplicationGatewayProbeHealthResponseMatch | None = ...,
        port: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["match", b"match"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "interval", b"interval", "match", b"match", "min_servers", b"min_servers", "name", b"name", "path", b"path", "pick_host_name_from_backend_http_settings", b"pick_host_name_from_backend_http_settings", "port", b"port", "protocol", b"protocol", "timeout", b"timeout", "unhealthy_threshold", b"unhealthy_threshold"]) -> None: ...

global___ApplicationGatewayProbe = ApplicationGatewayProbe

@typing_extensions.final
class ApplicationGatewayProbeHealthResponseMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BODY_FIELD_NUMBER: builtins.int
    STATUS_CODES_FIELD_NUMBER: builtins.int
    body: builtins.str
    @property
    def status_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        body: builtins.str = ...,
        status_codes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body", "status_codes", b"status_codes"]) -> None: ...

global___ApplicationGatewayProbeHealthResponseMatch = ApplicationGatewayProbeHealthResponseMatch

@typing_extensions.final
class ApplicationGatewayFrontendPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    port: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        port: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "port", b"port"]) -> None: ...

global___ApplicationGatewayFrontendPort = ApplicationGatewayFrontendPort

@typing_extensions.final
class ApplicationGatewayFrontendIPConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_IP_ADDRESS_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ALLOCATION_METHOD_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_CONFIGURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PUBLIC_IP_ADDRESS_FIELD_NUMBER: builtins.int
    private_ip_address: builtins.str
    private_ip_allocation_method: builtins.str
    @property
    def subnet(self) -> global___Subnet: ...
    private_link_configuration: builtins.str
    name: builtins.str
    @property
    def public_ip_address(self) -> global___PublicIpAddress: ...
    def __init__(
        self,
        *,
        private_ip_address: builtins.str = ...,
        private_ip_allocation_method: builtins.str = ...,
        subnet: global___Subnet | None = ...,
        private_link_configuration: builtins.str = ...,
        name: builtins.str = ...,
        public_ip_address: global___PublicIpAddress | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["public_ip_address", b"public_ip_address", "subnet", b"subnet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_ip_address", b"private_ip_address", "private_ip_allocation_method", b"private_ip_allocation_method", "private_link_configuration", b"private_link_configuration", "public_ip_address", b"public_ip_address", "subnet", b"subnet"]) -> None: ...

global___ApplicationGatewayFrontendIPConfiguration = ApplicationGatewayFrontendIPConfiguration

@typing_extensions.final
class ApplicationGatewaySslCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    KEY_VAULT_SECRET_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    data: builtins.str
    password: builtins.str
    key_vault_secret_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        data: builtins.str = ...,
        password: builtins.str = ...,
        key_vault_secret_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "key_vault_secret_id", b"key_vault_secret_id", "name", b"name", "password", b"password"]) -> None: ...

global___ApplicationGatewaySslCertificate = ApplicationGatewaySslCertificate

@typing_extensions.final
class ApplicationGatewayTrustedClientCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    data: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        data: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "name", b"name"]) -> None: ...

global___ApplicationGatewayTrustedClientCertificate = ApplicationGatewayTrustedClientCertificate

@typing_extensions.final
class ApplicationGatewayTrustedRootCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    KEY_VAULT_SECRET_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    data: builtins.str
    key_vault_secret_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        data: builtins.str = ...,
        key_vault_secret_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "key_vault_secret_id", b"key_vault_secret_id", "name", b"name"]) -> None: ...

global___ApplicationGatewayTrustedRootCertificate = ApplicationGatewayTrustedRootCertificate

@typing_extensions.final
class ApplicationGatewayAuthenticationCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    data: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        data: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "name", b"name"]) -> None: ...

global___ApplicationGatewayAuthenticationCertificate = ApplicationGatewayAuthenticationCertificate

@typing_extensions.final
class ApplicationGatewayIPConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def subnet(self) -> global___Subnet: ...
    name: builtins.str
    def __init__(
        self,
        *,
        subnet: global___Subnet | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subnet", b"subnet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "subnet", b"subnet"]) -> None: ...

global___ApplicationGatewayIPConfiguration = ApplicationGatewayIPConfiguration

@typing_extensions.final
class ApplicationGatewaySslPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_SSL_PROTOCOLS_FIELD_NUMBER: builtins.int
    POLICY_TYPE_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    CIPHER_SUITES_FIELD_NUMBER: builtins.int
    MIN_PROTOCOL_VERSION_FIELD_NUMBER: builtins.int
    @property
    def disabled_ssl_protocols(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    policy_type: builtins.str
    policy_name: builtins.str
    @property
    def cipher_suites(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    min_protocol_version: builtins.str
    def __init__(
        self,
        *,
        disabled_ssl_protocols: collections.abc.Iterable[builtins.str] | None = ...,
        policy_type: builtins.str = ...,
        policy_name: builtins.str = ...,
        cipher_suites: collections.abc.Iterable[builtins.str] | None = ...,
        min_protocol_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cipher_suites", b"cipher_suites", "disabled_ssl_protocols", b"disabled_ssl_protocols", "min_protocol_version", b"min_protocol_version", "policy_name", b"policy_name", "policy_type", b"policy_type"]) -> None: ...

global___ApplicationGatewaySslPolicy = ApplicationGatewaySslPolicy

@typing_extensions.final
class ApplicationGatewaySku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    CAPACITY_FIELD_NUMBER: builtins.int
    name: builtins.str
    tier: builtins.str
    capacity: builtins.int
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        tier: builtins.str = ...,
        capacity: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "name", b"name", "tier", b"tier"]) -> None: ...

global___ApplicationGatewaySku = ApplicationGatewaySku

@typing_extensions.final
class ApplicationGatewayWebApplicationFirewallPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    POLICY_SETTINGS_FIELD_NUMBER: builtins.int
    CUSTOM_RULES_FIELD_NUMBER: builtins.int
    MANAGED_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def policy_settings(self) -> global___PolicySettings: ...
    @property
    def custom_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WebApplicationFirewallCustomRule]: ...
    @property
    def managed_rules(self) -> global___ManagedRulesDefinition: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        policy_settings: global___PolicySettings | None = ...,
        custom_rules: collections.abc.Iterable[global___WebApplicationFirewallCustomRule] | None = ...,
        managed_rules: global___ManagedRulesDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["managed_rules", b"managed_rules", "policy_settings", b"policy_settings", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_rules", b"custom_rules", "location", b"location", "managed_rules", b"managed_rules", "name", b"name", "policy_settings", b"policy_settings", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___ApplicationGatewayWebApplicationFirewallPolicies = ApplicationGatewayWebApplicationFirewallPolicies

@typing_extensions.final
class ManagedRulesDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXCLUSIONS_FIELD_NUMBER: builtins.int
    MANAGED_RULE_SETS_FIELD_NUMBER: builtins.int
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OwaspCrsExclusionEntry]: ...
    @property
    def managed_rule_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleSet]: ...
    def __init__(
        self,
        *,
        exclusions: collections.abc.Iterable[global___OwaspCrsExclusionEntry] | None = ...,
        managed_rule_sets: collections.abc.Iterable[global___ManagedRuleSet] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclusions", b"exclusions", "managed_rule_sets", b"managed_rule_sets"]) -> None: ...

global___ManagedRulesDefinition = ManagedRulesDefinition

@typing_extensions.final
class ManagedRuleSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_SET_TYPE_FIELD_NUMBER: builtins.int
    RULE_SET_VERSION_FIELD_NUMBER: builtins.int
    RULE_GROUP_OVERRIDES_FIELD_NUMBER: builtins.int
    rule_set_type: builtins.str
    rule_set_version: builtins.str
    @property
    def rule_group_overrides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleGroupOverride]: ...
    def __init__(
        self,
        *,
        rule_set_type: builtins.str = ...,
        rule_set_version: builtins.str = ...,
        rule_group_overrides: collections.abc.Iterable[global___ManagedRuleGroupOverride] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rule_group_overrides", b"rule_group_overrides", "rule_set_type", b"rule_set_type", "rule_set_version", b"rule_set_version"]) -> None: ...

global___ManagedRuleSet = ManagedRuleSet

@typing_extensions.final
class ManagedRuleGroupOverride(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_GROUP_NAME_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    rule_group_name: builtins.str
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleOverride]: ...
    def __init__(
        self,
        *,
        rule_group_name: builtins.str = ...,
        rules: collections.abc.Iterable[global___ManagedRuleOverride] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rule_group_name", b"rule_group_name", "rules", b"rules"]) -> None: ...

global___ManagedRuleGroupOverride = ManagedRuleGroupOverride

@typing_extensions.final
class ManagedRuleOverride(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rule_id", b"rule_id", "state", b"state"]) -> None: ...

global___ManagedRuleOverride = ManagedRuleOverride

@typing_extensions.final
class OwaspCrsExclusionEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_VARIABLE_FIELD_NUMBER: builtins.int
    SELECTOR_MATCH_OPERATOR_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    match_variable: builtins.str
    selector_match_operator: builtins.str
    selector: builtins.str
    def __init__(
        self,
        *,
        match_variable: builtins.str = ...,
        selector_match_operator: builtins.str = ...,
        selector: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_variable", b"match_variable", "selector", b"selector", "selector_match_operator", b"selector_match_operator"]) -> None: ...

global___OwaspCrsExclusionEntry = OwaspCrsExclusionEntry

@typing_extensions.final
class WebApplicationFirewallCustomRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    RULE_TYPE_FIELD_NUMBER: builtins.int
    MATCH_CONDITIONS_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    priority: builtins.int
    rule_type: builtins.str
    @property
    def match_conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchCondition]: ...
    action: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        priority: builtins.int = ...,
        rule_type: builtins.str = ...,
        match_conditions: collections.abc.Iterable[global___MatchCondition] | None = ...,
        action: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "match_conditions", b"match_conditions", "name", b"name", "priority", b"priority", "rule_type", b"rule_type"]) -> None: ...

global___WebApplicationFirewallCustomRule = WebApplicationFirewallCustomRule

@typing_extensions.final
class MatchCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_VARIABLES_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    NEGATION_CONDITON_FIELD_NUMBER: builtins.int
    MATCH_VALUES_FIELD_NUMBER: builtins.int
    TRANSFORMS_FIELD_NUMBER: builtins.int
    @property
    def match_variables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchVariable]: ...
    operator: builtins.str
    negation_conditon: builtins.bool
    @property
    def match_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def transforms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        match_variables: collections.abc.Iterable[global___MatchVariable] | None = ...,
        operator: builtins.str = ...,
        negation_conditon: builtins.bool = ...,
        match_values: collections.abc.Iterable[builtins.str] | None = ...,
        transforms: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_values", b"match_values", "match_variables", b"match_variables", "negation_conditon", b"negation_conditon", "operator", b"operator", "transforms", b"transforms"]) -> None: ...

global___MatchCondition = MatchCondition

@typing_extensions.final
class MatchVariable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VARIABLE_NAME_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    variable_name: builtins.str
    selector: builtins.str
    def __init__(
        self,
        *,
        variable_name: builtins.str = ...,
        selector: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["selector", b"selector", "variable_name", b"variable_name"]) -> None: ...

global___MatchVariable = MatchVariable

@typing_extensions.final
class PolicySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    REQUEST_BODY_CHECK_FIELD_NUMBER: builtins.int
    MAX_REQUEST_BODY_SIZE_IN_KB_FIELD_NUMBER: builtins.int
    FILE_UPLOAD_LIMIT_IN_MB_FIELD_NUMBER: builtins.int
    state: builtins.str
    mode: builtins.str
    request_body_check: builtins.bool
    max_request_body_size_in_kb: builtins.int
    file_upload_limit_in_mb: builtins.int
    def __init__(
        self,
        *,
        state: builtins.str = ...,
        mode: builtins.str = ...,
        request_body_check: builtins.bool = ...,
        max_request_body_size_in_kb: builtins.int = ...,
        file_upload_limit_in_mb: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_upload_limit_in_mb", b"file_upload_limit_in_mb", "max_request_body_size_in_kb", b"max_request_body_size_in_kb", "mode", b"mode", "request_body_check", b"request_body_check", "state", b"state"]) -> None: ...

global___PolicySettings = PolicySettings



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class EventBus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EVENT_SOURCE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    event_source_name: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        event_source_name: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_source_name", b"event_source_name", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___EventBus = EventBus

@typing_extensions.final
class Events(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_BUS_FIELD_NUMBER: builtins.int
    EVENT_BUS_POLICY_FIELD_NUMBER: builtins.int
    RULE_FIELD_NUMBER: builtins.int
    @property
    def event_bus(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EventBus]: ...
    @property
    def event_bus_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EventBusPolicy]: ...
    @property
    def rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Rule]: ...
    def __init__(
        self,
        *,
        event_bus: collections.abc.Iterable[global___EventBus] | None = ...,
        event_bus_policy: collections.abc.Iterable[global___EventBusPolicy] | None = ...,
        rule: collections.abc.Iterable[global___Rule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_bus", b"event_bus", "event_bus_policy", b"event_bus_policy", "rule", b"rule"]) -> None: ...

global___Events = Events

@typing_extensions.final
class EventBusPolicyCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___EventBusPolicyCondition = EventBusPolicyCondition

@typing_extensions.final
class EventBusPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EVENT_BUS_NAME_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    STATEMENT_ID_FIELD_NUMBER: builtins.int
    PRINCIPAL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    event_bus_name: builtins.str
    @property
    def condition(self) -> global___EventBusPolicyCondition: ...
    action: builtins.str
    statement_id: builtins.str
    principal: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        event_bus_name: builtins.str = ...,
        condition: global___EventBusPolicyCondition | None = ...,
        action: builtins.str = ...,
        statement_id: builtins.str = ...,
        principal: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "condition", b"condition", "event_bus_name", b"event_bus_name", "principal", b"principal", "resource_info", b"resource_info", "statement_id", b"statement_id"]) -> None: ...

global___EventBusPolicy = EventBusPolicy

@typing_extensions.final
class RuleBatchArrayProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    size: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "size", b"size"]) -> None: ...

global___RuleBatchArrayProperties = RuleBatchArrayProperties

@typing_extensions.final
class RuleBatchRetryStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTEMPTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    attempts: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attempts: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attempts", b"attempts", "resource_info", b"resource_info"]) -> None: ...

global___RuleBatchRetryStrategy = RuleBatchRetryStrategy

@typing_extensions.final
class RuleBatchParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ARRAY_PROPERTIES_FIELD_NUMBER: builtins.int
    JOB_DEFINITION_FIELD_NUMBER: builtins.int
    JOB_NAME_FIELD_NUMBER: builtins.int
    RETRY_STRATEGY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def array_properties(self) -> global___RuleBatchArrayProperties: ...
    job_definition: builtins.str
    job_name: builtins.str
    @property
    def retry_strategy(self) -> global___RuleBatchRetryStrategy: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        array_properties: global___RuleBatchArrayProperties | None = ...,
        job_definition: builtins.str = ...,
        job_name: builtins.str = ...,
        retry_strategy: global___RuleBatchRetryStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["array_properties", b"array_properties", "resource_info", b"resource_info", "retry_strategy", b"retry_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["array_properties", b"array_properties", "job_definition", b"job_definition", "job_name", b"job_name", "resource_info", b"resource_info", "retry_strategy", b"retry_strategy"]) -> None: ...

global___RuleBatchParameters = RuleBatchParameters

@typing_extensions.final
class RuleAwsVpcConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    SUBNETS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    assign_public_ip: builtins.str
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        assign_public_ip: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        subnets: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assign_public_ip", b"assign_public_ip", "resource_info", b"resource_info", "security_groups", b"security_groups", "subnets", b"subnets"]) -> None: ...

global___RuleAwsVpcConfiguration = RuleAwsVpcConfiguration

@typing_extensions.final
class RuleNetworkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AWS_VPC_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def aws_vpc_configuration(self) -> global___RuleAwsVpcConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        aws_vpc_configuration: global___RuleAwsVpcConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_vpc_configuration", b"aws_vpc_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_vpc_configuration", b"aws_vpc_configuration", "resource_info", b"resource_info"]) -> None: ...

global___RuleNetworkConfiguration = RuleNetworkConfiguration

@typing_extensions.final
class RuleEcsParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    LAUNCH_TYPE_FIELD_NUMBER: builtins.int
    NETWORK_CONFIGURATION_FIELD_NUMBER: builtins.int
    PLATFORM_VERSION_FIELD_NUMBER: builtins.int
    TASK_COUNT_FIELD_NUMBER: builtins.int
    TASK_DEFINITION_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    group: builtins.str
    launch_type: builtins.str
    @property
    def network_configuration(self) -> global___RuleNetworkConfiguration: ...
    platform_version: builtins.str
    task_count: builtins.int
    task_definition_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        group: builtins.str = ...,
        launch_type: builtins.str = ...,
        network_configuration: global___RuleNetworkConfiguration | None = ...,
        platform_version: builtins.str = ...,
        task_count: builtins.int = ...,
        task_definition_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_configuration", b"network_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group", b"group", "launch_type", b"launch_type", "network_configuration", b"network_configuration", "platform_version", b"platform_version", "resource_info", b"resource_info", "task_count", b"task_count", "task_definition_arn", b"task_definition_arn"]) -> None: ...

global___RuleEcsParameters = RuleEcsParameters

@typing_extensions.final
class RuleHttpParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HeaderParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class QueryStringParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HEADER_PARAMETERS_FIELD_NUMBER: builtins.int
    PATH_PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    QUERY_STRING_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def header_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def path_parameter_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def query_string_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        header_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        path_parameter_values: collections.abc.Iterable[builtins.str] | None = ...,
        query_string_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_parameters", b"header_parameters", "path_parameter_values", b"path_parameter_values", "query_string_parameters", b"query_string_parameters", "resource_info", b"resource_info"]) -> None: ...

global___RuleHttpParameters = RuleHttpParameters

@typing_extensions.final
class RuleInputTransformer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class InputPathsMapEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INPUT_PATHS_MAP_FIELD_NUMBER: builtins.int
    INPUT_TEMPLATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def input_paths_map(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    input_template: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        input_paths_map: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        input_template: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input_paths_map", b"input_paths_map", "input_template", b"input_template", "resource_info", b"resource_info"]) -> None: ...

global___RuleInputTransformer = RuleInputTransformer

@typing_extensions.final
class RuleKinesisParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARTITION_KEY_PATH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    partition_key_path: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        partition_key_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["partition_key_path", b"partition_key_path", "resource_info", b"resource_info"]) -> None: ...

global___RuleKinesisParameters = RuleKinesisParameters

@typing_extensions.final
class RuleRunCommandTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___RuleRunCommandTarget = RuleRunCommandTarget

@typing_extensions.final
class RuleRunCommandParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RUN_COMMAND_TARGETS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def run_command_targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RuleRunCommandTarget]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        run_command_targets: collections.abc.Iterable[global___RuleRunCommandTarget] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "run_command_targets", b"run_command_targets"]) -> None: ...

global___RuleRunCommandParameters = RuleRunCommandParameters

@typing_extensions.final
class RuleSqsParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MESSAGE_GROUP_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    message_group_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        message_group_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message_group_id", b"message_group_id", "resource_info", b"resource_info"]) -> None: ...

global___RuleSqsParameters = RuleSqsParameters

@typing_extensions.final
class RuleTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ARN_FIELD_NUMBER: builtins.int
    BATCH_PARAMETERS_FIELD_NUMBER: builtins.int
    ECS_PARAMETERS_FIELD_NUMBER: builtins.int
    HTTP_PARAMETERS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    INPUT_PATH_FIELD_NUMBER: builtins.int
    INPUT_TRANSFORMER_FIELD_NUMBER: builtins.int
    KINESIS_PARAMETERS_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    RUN_COMMAND_PARAMETERS_FIELD_NUMBER: builtins.int
    SQS_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    arn: builtins.str
    @property
    def batch_parameters(self) -> global___RuleBatchParameters: ...
    @property
    def ecs_parameters(self) -> global___RuleEcsParameters: ...
    @property
    def http_parameters(self) -> global___RuleHttpParameters: ...
    id: builtins.str
    input: builtins.str
    input_path: builtins.str
    @property
    def input_transformer(self) -> global___RuleInputTransformer: ...
    @property
    def kinesis_parameters(self) -> global___RuleKinesisParameters: ...
    role_arn: builtins.str
    @property
    def run_command_parameters(self) -> global___RuleRunCommandParameters: ...
    @property
    def sqs_parameters(self) -> global___RuleSqsParameters: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        arn: builtins.str = ...,
        batch_parameters: global___RuleBatchParameters | None = ...,
        ecs_parameters: global___RuleEcsParameters | None = ...,
        http_parameters: global___RuleHttpParameters | None = ...,
        id: builtins.str = ...,
        input: builtins.str = ...,
        input_path: builtins.str = ...,
        input_transformer: global___RuleInputTransformer | None = ...,
        kinesis_parameters: global___RuleKinesisParameters | None = ...,
        role_arn: builtins.str = ...,
        run_command_parameters: global___RuleRunCommandParameters | None = ...,
        sqs_parameters: global___RuleSqsParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_parameters", b"batch_parameters", "ecs_parameters", b"ecs_parameters", "http_parameters", b"http_parameters", "input_transformer", b"input_transformer", "kinesis_parameters", b"kinesis_parameters", "resource_info", b"resource_info", "run_command_parameters", b"run_command_parameters", "sqs_parameters", b"sqs_parameters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arn", b"arn", "batch_parameters", b"batch_parameters", "ecs_parameters", b"ecs_parameters", "http_parameters", b"http_parameters", "id", b"id", "input", b"input", "input_path", b"input_path", "input_transformer", b"input_transformer", "kinesis_parameters", b"kinesis_parameters", "resource_info", b"resource_info", "role_arn", b"role_arn", "run_command_parameters", b"run_command_parameters", "sqs_parameters", b"sqs_parameters"]) -> None: ...

global___RuleTarget = RuleTarget

@typing_extensions.final
class Rule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class EventPatternEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EVENT_BUS_NAME_FIELD_NUMBER: builtins.int
    EVENT_PATTERN_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    SCHEDULE_EXPRESSION_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    event_bus_name: builtins.str
    @property
    def event_pattern(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    role_arn: builtins.str
    schedule_expression: builtins.str
    state: builtins.str
    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RuleTarget]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        event_bus_name: builtins.str = ...,
        event_pattern: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        role_arn: builtins.str = ...,
        schedule_expression: builtins.str = ...,
        state: builtins.str = ...,
        targets: collections.abc.Iterable[global___RuleTarget] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "event_bus_name", b"event_bus_name", "event_pattern", b"event_pattern", "name", b"name", "resource_info", b"resource_info", "role_arn", b"role_arn", "schedule_expression", b"schedule_expression", "state", b"state", "targets", b"targets"]) -> None: ...

global___Rule = Rule



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_http.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agcp/gcp_compute_http.proto\x12\x1coak9.tython.gcp.compute_http\x1a\x13shared/shared.proto\"Q\n\x1f\x43omputeHttpHealthCheckXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xac\x03\n\x16\x43omputeHttpHealthCheck\x12\x1a\n\x12\x63heck_interval_sec\x18\x01 \x01(\x01\x12\x1a\n\x12\x63reation_timestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x19\n\x11healthy_threshold\x18\x04 \x01(\x01\x12\x0c\n\x04host\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0c\n\x04port\x18\x08 \x01(\x01\x12\x0f\n\x07project\x18\t \x01(\t\x12\x14\n\x0crequest_path\x18\n \x01(\t\x12\x11\n\tself_link\x18\x0b \x01(\t\x12\x13\n\x0btimeout_sec\x18\x0c \x01(\x01\x12\x1b\n\x13unhealthy_threshold\x18\r \x01(\x01\x12O\n\x08timeouts\x18\x0e \x01(\x0b\x32=.oak9.tython.gcp.compute_http.ComputeHttpHealthCheckXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_http_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEHTTPHEALTHCHECKXTIMEOUTS._serialized_start=81
  _COMPUTEHTTPHEALTHCHECKXTIMEOUTS._serialized_end=162
  _COMPUTEHTTPHEALTHCHECK._serialized_start=165
  _COMPUTEHTTPHEALTHCHECK._serialized_end=593
# @@protoc_insertion_point(module_scope)
